@@ -5,6 +5,10 @@
 #include <Wt/WPushButton.h>
 #include <Wt/WText.h>
 
+#ifdef WT_TARGET_JAVA
+using namespace Wt;
+#endif // WT_TARGET_JAVA
+
 SAMPLE_BEGIN(FileUpload)
 
 auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
